@@ -88,13 +88,15 @@ procdialog_create_kill_dialog (ProcData *procdata, int signal)
 						    static_cast<GtkDialogFlags>(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
 						    GTK_MESSAGE_WARNING,
 						    GTK_BUTTONS_NONE,
-						    _(primary));
+						    "%s",
+						    primary);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (kill_alert_dialog),
-						  _(secondary));
+						  "%s",
+						  secondary);
 
 	gtk_dialog_add_buttons (GTK_DIALOG (kill_alert_dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				_(button_text), GTK_RESPONSE_OK,
+				button_text, GTK_RESPONSE_OK,
 				NULL);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (kill_alert_dialog),
@@ -283,6 +285,17 @@ solaris_mode_toggled(GtkToggleButton *button, gpointer data)
 }
 
 
+static void
+network_in_bits_toggled(GtkToggleButton *button, gpointer data)
+{
+	ProcData *procdata = static_cast<ProcData*>(data);
+	GConfClient *client = procdata->client;
+	gboolean toggled;
+	toggled = gtk_toggle_button_get_active(button);
+	gconf_client_set_bool(client, procman::gconf::network_in_bits.c_str(), toggled, NULL);
+}
+
+
 
 static void
 smooth_refresh_toggled(GtkToggleButton *button, gpointer data)
@@ -376,12 +389,12 @@ field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 }
 
 static GtkWidget *
-create_proc_field_page (ProcData *procdata)
+create_field_page(GtkWidget *tree, const char* text)
 {
 	GtkWidget *vbox;
 	GtkWidget *scrolled;
 	GtkWidget *label;
-	GtkWidget *tree = procdata->tree, *treeview;
+	GtkWidget *treeview;
 	GList *it, *columns;
 	GtkListStore *model;
 	GtkTreeViewColumn *column;
@@ -389,7 +402,7 @@ create_proc_field_page (ProcData *procdata)
 
 	vbox = gtk_vbox_new (FALSE, 6);
 	
-	label = gtk_label_new_with_mnemonic (_("Process i_nformation shown in list:"));
+	label = gtk_label_new_with_mnemonic (text);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 
@@ -469,19 +482,17 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	GtkWidget *proc_box;
 	GtkWidget *sys_box;
 	GtkWidget *main_vbox;
-	GtkWidget *vbox, *vbox2;
+	GtkWidget *vbox, *vbox2, *vbox3;
 	GtkWidget *hbox, *hbox2, *hbox3;
 	GtkWidget *label;
 	GtkAdjustment *adjustment;
 	GtkWidget *spin_button;
 	GtkWidget *check_button;
 	GtkWidget *tab_label;
-	GtkWidget *color_picker;
 	GtkWidget *smooth_button;
 	GtkSizeGroup *size;
 	gfloat update;
 	gchar *tmp;
-	GdkColor color;
 	
 	if (prefs_dialog)
 		return;
@@ -621,7 +632,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	label = gtk_label_new ("    ");
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
-	vbox2 = create_proc_field_page (procdata);
+	vbox2 = create_field_page (procdata->tree, _("Process i_nformation shown in list:"));
 	gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
 	
 	sys_box = gtk_vbox_new (FALSE, 12);
@@ -670,46 +681,22 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
 	
+
+	GtkWidget *bits_button;
+	bits_button = gtk_check_button_new_with_mnemonic(_("Show network speed in bits"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bits_button),
+				     gconf_client_get_bool(procdata->client,
+							   procman::gconf::network_in_bits.c_str(),
+							   NULL));
+	g_signal_connect(G_OBJECT(bits_button), "toggled",
+			 G_CALLBACK(network_in_bits_toggled), procdata);
+	gtk_box_pack_start(GTK_BOX(vbox2), bits_button, TRUE, TRUE, 0);
+
+
 	
 	hbox2 = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, TRUE, TRUE, 0);
 	
-	label = gtk_label_new_with_mnemonic (_("_Background color:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
-	gtk_size_group_add_widget (size, label);
-	
-	color.red   = procdata->config.bg_color.red;
-	color.green = procdata->config.bg_color.green;
-   	color.blue  = procdata->config.bg_color.blue;
-	color_picker = gtk_color_button_new_with_color (&color);
-
-	g_signal_connect (G_OBJECT (color_picker), "color_set",
-			          G_CALLBACK (cb_bg_color_changed), procdata);
-	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, FALSE, FALSE, 0);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
-	gtk_widget_show (color_picker);
-		
-	hbox2 = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, TRUE, TRUE, 0);
-	  
-	label = gtk_label_new_with_mnemonic (_("_Grid color:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
-	gtk_size_group_add_widget (size, label);
-	
-	color.red   = procdata->config.frame_color.red;
-	color.green = procdata->config.frame_color.green;
-   	color.blue  = procdata->config.frame_color.blue;
-	color_picker = gtk_color_button_new_with_color (&color);
-	
-	g_signal_connect (G_OBJECT (color_picker), "color_set",
-			    G_CALLBACK (cb_frame_color_changed), procdata);	  
-	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, FALSE, FALSE, 0);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
-	gtk_widget_show (color_picker);
-
-
 	/*
 	 * Devices
 	 */
@@ -766,6 +753,27 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox2), check_button, FALSE, FALSE, 0);
 
 
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
+
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (vbox2), label, FALSE, FALSE, 0);
+	
+	tmp = g_strdup_printf ("<b>%s</b>", _("Information Fields"));
+	label = gtk_label_new (NULL);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_label_set_markup (GTK_LABEL (label), tmp);
+	g_free (tmp);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
+	
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	
+	vbox3 = create_field_page (procdata->disk_list, _("File system i_nformation shown in list:"));
+	gtk_box_pack_start (GTK_BOX (hbox), vbox3, TRUE, TRUE, 0);
 
 	gtk_widget_show_all (dialog);
 	g_signal_connect (G_OBJECT (dialog), "response",
